/**
 * tdesign v1.13.1
 * (c) 2025 tdesign
 * @license MIT
 */

'use strict';

var _typeof = require('./dep-c83f28a0.js');

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */
function isObjectLike(value) {
  return value != null && _typeof._typeof(value) == 'object';
}

exports.isObjectLike = isObjectLike;
//# sourceMappingURL=dep-0fccdcfb.js.map
